==> skill-core-16.0.2-sources.jar: com/ptteng/common/skill/service/ProjectService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.Project;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface ProjectService extends BaseDaoService {

	



   		   
		
		public Long insert(Project project)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Project> insertList(List<Project> projectList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(Project project)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<Project> projectList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public Project getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Project> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countProjectIdsByGidOrderByCreateAt(Long gid)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getProjectIdsByGidOrderByCreateAt(Long gid, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getProjectIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countProjectIds() throws ServiceException, ServiceDaoException;
	

}

==> skill-core-30.0.0-sources.jar: com/ptteng/common/skill/service/ProjectService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.Project;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface ProjectService extends BaseDaoService {

	



   		   
		
		public Long insert(Project project)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Project> insertList(List<Project> projectList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(Project project)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<Project> projectList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public Project getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<Project> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countProjectIdsByIterationIdOrderByCreateAt(Long iterationId)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countProjectIdsByTidAndStatusOrderByCreateAt(Long tid, Integer status)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countProjectIdsByTidOrderByCreateAt(Long tid)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countProjectIdsByNameOrderByCreateAt(String name)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getProjectIdsByIterationIdOrderByCreateAt(Long iterationId, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getProjectIdsByTidAndStatusOrderByCreateAt(Long tid, Integer status, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getProjectIdsByTidOrderByCreateAt(Long tid, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getProjectIdsByNameOrderByCreateAt(String name, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getProjectIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countProjectIds() throws ServiceException, ServiceDaoException;
	

}
